Module args

Module args 

Command line argument parsing: DftArgs

Structs

DftArgs

Enums

Command
FlightSqlCommand
Parameters for each command match to exactly how they are defined in specification (https://arrow.apache.org/docs/format/FlightSql.html#protocol-buffer-definitions)
TpchFormat

Functions

parse_headers_file
Parse headers from a file supporting both simple and curl config formats