pub struct ExecutionContext { /* private fields */ }Expand description
Structure for executing queries locally
This context includes both:
-
The configuration of a
SessionContextwith various extensions enabled -
The code for running SQL queries
The design goals for this module are to serve as an example of how to integrate DataFusion into an application and to provide a simple interface for running SQL queries with the various extensions enabled.
Thus it is important (eventually) not depend on the code in the app crate
Implementations
Sourceimpl ExecutionContext
impl ExecutionContext
Sourcepub fn try_new(
config: &ExecutionConfig,
session_state: SessionState,
app_type: AppType,
) -> Result<Self>
pub fn try_new( config: &ExecutionConfig, session_state: SessionState, app_type: AppType, ) -> Result<Self>
Construct a new ExecutionContext with the specified configuration
pub fn config(&self) -> &ExecutionConfig
pub fn create_tables(&mut self) -> Result<()>
Sourcepub fn session_ctx(&self) -> &SessionContext
pub fn session_ctx(&self) -> &SessionContext
Return the inner DataFusion SessionContext
Sourcepub fn executor(&self) -> &Option<DedicatedExecutor>
pub fn executor(&self) -> &Option<DedicatedExecutor>
Return the inner DedicatedExecutor
Sourcepub async fn statement_to_logical_plan(
&self,
statement: Statement,
) -> Result<LogicalPlan>
pub async fn statement_to_logical_plan( &self, statement: Statement, ) -> Result<LogicalPlan>
Convert the statement to a LogicalPlan. Uses the DedicatedExecutor if it is available.
Sourcepub async fn execute_logical_plan(
&self,
logical_plan: LogicalPlan,
) -> Result<SendableRecordBatchStream>
pub async fn execute_logical_plan( &self, logical_plan: LogicalPlan, ) -> Result<SendableRecordBatchStream>
Executes the provided LogicalPlan returning a SendableRecordBatchStream. Uses the DedicatedExecutor if it is available.
Sourcepub async fn execute_sql_and_discard_results(&self, sql: &str) -> Result<()>
pub async fn execute_sql_and_discard_results(&self, sql: &str) -> Result<()>
Executes the specified sql string, driving it to completion but discarding any results
Sourcepub async fn create_physical_plan(
&self,
sql: &str,
) -> Result<Arc<dyn ExecutionPlan>>
pub async fn create_physical_plan( &self, sql: &str, ) -> Result<Arc<dyn ExecutionPlan>>
Create a physical plan from the specified SQL string. This is useful if you want to store the plan and collect metrics from it.
Sourcepub async fn execute_sql(&self, sql: &str) -> Result<SendableRecordBatchStream>
pub async fn execute_sql(&self, sql: &str) -> Result<SendableRecordBatchStream>
Executes the specified sql string, returning the resulting
SendableRecordBatchStream of results
Sourcepub async fn execute_statement(
&self,
statement: Statement,
) -> Result<SendableRecordBatchStream>
pub async fn execute_statement( &self, statement: Statement, ) -> Result<SendableRecordBatchStream>
Executes the a pre-parsed DataFusion Statement, returning the
resulting SendableRecordBatchStream of results
Sourcepub fn load_ddl(&self) -> Option<String>
pub fn load_ddl(&self) -> Option<String>
Load DDL from configured DDL path for execution (so strips out comments and empty lines)
Sourcepub async fn execute_ddl(&self)
pub async fn execute_ddl(&self)
Execute DDL statements sequentially
Sourcepub async fn benchmark_query(
&self,
query: &str,
cli_iterations: Option<usize>,
) -> Result<LocalBenchmarkStats>
pub async fn benchmark_query( &self, query: &str, cli_iterations: Option<usize>, ) -> Result<LocalBenchmarkStats>
Benchmark the provided query. Currently, only a single statement can be benchmarked
pub async fn analyze_query(&self, query: &str) -> Result<ExecutionStats>