pub struct DftSessionStateBuilder { /* private fields */ }Expand description
Builds a DataFusion SessionState with any necessary configuration
Ideally we would use the DataFusion SessionStateBuilder, but it doesn’t
currently have all the needed APIs. Once we have a good handle on the needed
APIs we can upstream them to DataFusion.
List of things that would be nice to add upstream: TODO: Implement Debug for SessionStateBuilder upstream https://github.com/apache/datafusion/issues/12555 TODO: Implement some way to get access to the current RuntimeEnv (to register object stores) https://github.com/apache/datafusion/issues/12553 TODO: Implement a way to add just a single TableProviderFactory https://github.com/apache/datafusion/issues/12552 TODO: Make TableFactoryProvider implement Debug https://github.com/apache/datafusion/pull/12557 TODO: rename RuntimeEnv::new() to RuntimeEnv::try_new() as it returns a Result: https://github.com/apache/datafusion/issues/12554
Implementations
Sourceimpl DftSessionStateBuilder
impl DftSessionStateBuilder
pub fn with_app_type(self, app_type: AppType) -> Self
pub fn with_execution_config(self, app_type: ExecutionConfig) -> Self
Sourcepub fn with_batch_size(self, batch_size: usize) -> Self
pub fn with_batch_size(self, batch_size: usize) -> Self
Set the batch_size on the SessionConfig
Sourcepub fn add_table_factory(
&mut self,
name: &str,
factory: Arc<dyn TableProviderFactory>,
)
pub fn add_table_factory( &mut self, name: &str, factory: Arc<dyn TableProviderFactory>, )
Add a table factory to the list of factories on this builder
Sourcepub fn add_catalog_provider(
&mut self,
name: &str,
factory: Arc<dyn CatalogProvider>,
)
pub fn add_catalog_provider( &mut self, name: &str, factory: Arc<dyn CatalogProvider>, )
Add a catalog provider to the list of providers on this builder
Sourcepub fn runtime_env(&mut self) -> &RuntimeEnv
pub fn runtime_env(&mut self) -> &RuntimeEnv
Return the current RuntimeEnv, creating a default if it doesn’t exist
pub async fn register_extension( &mut self, config: ExecutionConfig, extension: Arc<dyn Extension>, ) -> Result<()>
pub async fn with_extensions(self) -> Result<Self>
Sourcepub fn build(self) -> Result<SessionState>
pub fn build(self) -> Result<SessionState>
Build the SessionState from the specified configuration