Enum SelectedTab

pub enum SelectedTab {
    SQL,
    History,
    Logs,
    Context,
}

Variants



SQL



History



Logs



Context

Implementations

Source

impl SelectedTab

pub const fn from_repr(discriminant: usize) -> Option<SelectedTab>

Try to create Self from the raw representation

Source

impl SelectedTab

pub fn title(self, _app: &App<'_>) -> Line<'static>

pub fn previous(self) -> Self

Get the previous tab, if there is no previous tab return the current tab.

pub fn next(self) -> Self

Get the next tab, if there is no next tab return the current tab.

pub fn render(self, area: Rect, buf: &mut Buffer, app: &App<'_>)

Render the tab with the provided state.

This used to be an impl of Widget but we weren’t able to pass state as a paramter to the render method so moved to impl on the SelectedTab. It’s not clear if this will have future impact.