Command line argument parsing: DftArgs
Structs
Enums
- Command
- Flight
SqlCommand - Parameters for each command match to exactly how they are defined in specification (https://arrow.apache.org/docs/format/FlightSql.html#protocol-buffer-definitions)
- Tpch
Format
Functions
- parse_
headers_ file - Parse headers from a file supporting both simple and curl config formats